@@ -35,11 +35,11 @@
 #include <sys/types.h>
 #include <math.h>
 #include <stdio.h>
-#include "stconfig.h"
+#include "sox_i.h"
 #include "adpcm.h"
 
 typedef struct MsState {
-        st_sample_t  step;      /* step size */
+        sox_ssample_t  step;      /* step size */
         short iCoef[2];
 } MsState_t;
 
@@ -53,7 +53,7 @@ typedef struct MsState {
  * 1.0 is scaled to 0x100
  */
 static const
-st_sample_t stepAdjustTable[] = {
+sox_ssample_t stepAdjustTable[] = {
         230, 230, 230, 230, 307, 409, 512, 614,
         768, 614, 512, 409, 307, 230, 230, 230
 };
@@ -72,17 +72,17 @@ const short iCoef[7][2] = {
                         { 392,-232}
 };
 
-inline st_sample_t AdpcmDecode(st_sample_t c, MsState_t *state,
-                               st_sample_t sample1, st_sample_t sample2)
+static inline sox_ssample_t AdpcmDecode(sox_ssample_t c, MsState_t *state,
+                               sox_ssample_t sample1, sox_ssample_t sample2)
 {
-        st_sample_t vlin;
-        st_sample_t sample;
-        st_sample_t step;
+        sox_ssample_t vlin;
+        sox_ssample_t sample;
+        sox_ssample_t step;
 
         /** Compute next step value **/
         step = state->step;
         {
-                st_sample_t nstep;
+                sox_ssample_t nstep;
                 nstep = (stepAdjustTable[c] * step) >> 8;
                 state->step = (nstep < 16)? 16:nstep;
         }
@@ -103,7 +103,7 @@ inline st_sample_t AdpcmDecode(st_sample_t c, MsState_t *state,
 
 /* AdpcmBlockExpandI() outputs interleaved samples into one output buffer */
 const char *AdpcmBlockExpandI(
-        int chans,          /* total channels             */
+        unsigned chans,          /* total channels             */
         int nCoef,
         const short *iCoef,
         const unsigned char *ibuff,/* input buffer[blockAlign]   */
@@ -112,7 +112,7 @@ const char *AdpcmBlockExpandI(
 )
 {
         const unsigned char *ip;
-        int ch;
+        unsigned ch;
         const char *errmsg = NULL;
         MsState_t state[4];                                             /* One decompressor state for each channel */
 
@@ -141,7 +141,7 @@ const char *AdpcmBlockExpandI(
                 lsbshortldi(obuff[ch], ip);
 
         {
-                int ch;
+                unsigned ch;
                 unsigned char b;
                 short *op, *top, *tmp;
 
@@ -153,11 +153,11 @@ const char *AdpcmBlockExpandI(
                 while (op < top) {
                         b = *ip++;
                         tmp = op;
-                        *op++ = AdpcmDecode(b >> 4, state+ch, tmp[-chans], tmp[-2*chans]);
+                        *op++ = AdpcmDecode(b >> 4, state+ch, tmp[-chans], tmp[-(2*chans)]);
                         if (++ch == chans) ch = 0;
                         /* ch = ++ch % chans; */
                         tmp = op;
-                        *op++ = AdpcmDecode(b&0x0f, state+ch, tmp[-chans], tmp[-2*chans]);
+                        *op++ = AdpcmDecode(b&0x0f, state+ch, tmp[-chans], tmp[-(2*chans)]);
                         if (++ch == chans) ch = 0;
                         /* ch = ++ch % chans; */
                 }
@@ -166,15 +166,14 @@ const char *AdpcmBlockExpandI(
 }
 
 static int AdpcmMashS(
-        int ch,              /* channel number to encode, REQUIRE 0 <= ch < chans  */
-        int chans,           /* total channels */
+        unsigned ch,              /* channel number to encode, REQUIRE 0 <= ch < chans  */
+        unsigned chans,           /* total channels */
         SAMPL v[2],          /* values to use as starting 2 */
         const short iCoef[2],/* lin predictor coeffs */
         const SAMPL *ibuff,  /* ibuff[] is interleaved input samples */
         int n,               /* samples to encode PER channel */
         int *iostep,         /* input/output step, REQUIRE 16 <= *st <= 0x7fff */
-        unsigned char *obuff,       /* output buffer[blockAlign], or NULL for no output  */
-        int sho              /* nonzero for debug printout */
+        unsigned char *obuff /* output buffer[blockAlign], or NULL for no output  */
 )
 {
         const SAMPL *ip, *itop;
@@ -231,10 +230,9 @@ static int AdpcmMashS(
                 d2 += d*d; /* update square-error */
 
                 if (op) {   /* if we want output, put it in proper place */
-                        /* FIXME: does c<<0 work properly? */
                         op[ox>>3] |= (ox&4)? c:(c<<4);
                         ox += 4*chans;
-                        /* if (sho) fprintf(stderr,"%.1x",c); */
+                        sox_debug_more("%.1x",c);
 
                 }
 
@@ -243,74 +241,20 @@ static int AdpcmMashS(
                 if (step < 16) step = 16;
 
         }
-        /* if (sho && op) fprintf(stderr,"\n");*/
+        if (op) sox_debug_more("\n");
         d2 /= n; /* be sure it's non-negative */
-#ifdef DEBUG
-        if (sho) {
-                fprintf(stderr, "ch%d: st %d->%d, d %.1f\n", ch, *iostep, step, sqrt(d2));
-                fflush(stderr);
-        }
-#endif
+        sox_debug_more("ch%d: st %d->%d, d %.1f\n", ch, *iostep, step, sqrt(d2));
         *iostep = step;
         return (int) sqrt(d2);
 }
 
-#if 0
-
-static long AvgDelta(int ch, int chans, const SAMPL *ibuff, int n)
-{
-        const SAMPL *ip, *itop;
-        long v0;
-        long d1;
-
-        ip = ibuff + ch;
-        itop = ip + n*chans;
-        d1 = 0;
-        v0 = *ip;
-        ip += chans;
-        for ( ; ip < itop; ip+=chans) {
-                long v1;
-
-                v1 = *ip;
-                d1 = abs(v1-v0);
-                v0 = v1;
-        }
-        return (d1/(n-1));
-}
-
-static long ReAvgDelta(int ch, int chans, const SAMPL *ibuff, int n, int step)
-{
-        const SAMPL *ip, *itop;
-        long v0;
-        long d1;
-
-        ip = ibuff + ch;
-        itop = ip + n*chans;
-        d1 = 0;
-        v0 = *ip;
-        ip += chans;
-        for ( ; ip < itop; ip+=chans) {
-                long v1, c;
-
-                v1 = *ip;
-                c = abs(v1-v0);
-                if (step && c>2*step) c=2*step;
-                d1 += c;
-                v0 = v1;
-        }
-        return (d1/(n-1));
-}
-
-#endif
-
-inline void AdpcmMashChannel(
-        int ch,             /* channel number to encode, REQUIRE 0 <= ch < chans  */
-        int chans,          /* total channels */
+static inline void AdpcmMashChannel(
+        unsigned ch,             /* channel number to encode, REQUIRE 0 <= ch < chans  */
+        unsigned chans,          /* total channels */
         const SAMPL *ip,    /* ip[] is interleaved input samples */
         int n,              /* samples to encode PER channel, REQUIRE */
         int *st,            /* input/output steps, 16<=st[i] */
-        unsigned char *obuff,      /* output buffer[blockAlign] */
-        int opt             /* non-zero allows some cpu-intensive code to improve output */
+        unsigned char *obuff /* output buffer[blockAlign] */
 )
 {
         SAMPL v[2];
@@ -318,12 +262,6 @@ inline void AdpcmMashChannel(
         int d,dmin,k,kmin;
 
         n0 = n/2; if (n0>32) n0=32;
-#if 0
-        s0=ReAvgDelta(ch, chans, ip, n, 0);
-        s1=ReAvgDelta(ch, chans, ip, n, s0);
-        fprintf(stderr, "ReAvg%d: %d->%d (%d)\n", ch, s0,s1,*st);
-        fflush(stderr);
-#endif
         if (*st<16) *st = 16;
         v[1] = ip[ch];
         v[0] = ip[ch+chans];
@@ -336,13 +274,13 @@ inline void AdpcmMashChannel(
         for (k=0; k<7; k++) {
                 int d0,d1;
                 ss = s0 = *st;
-                d0=AdpcmMashS(ch, chans, v, iCoef[k], ip, n, &ss, NULL, 0); /* with step s0 */
+                d0=AdpcmMashS(ch, chans, v, iCoef[k], ip, n, &ss, NULL); /* with step s0 */
 
                 s1 = s0;
-                AdpcmMashS(ch, chans, v, iCoef[k], ip, n0, &s1, NULL, 0);
-                /* fprintf(stderr," s32 %d\n",s1); */
+                AdpcmMashS(ch, chans, v, iCoef[k], ip, n0, &s1, NULL);
+                sox_debug_more(" s32 %d\n",s1);
                 ss = s1 = (3*s0+s1)/4;
-                d1=AdpcmMashS(ch, chans, v, iCoef[k], ip, n, &ss, NULL, 0); /* with step s1 */
+                d1=AdpcmMashS(ch, chans, v, iCoef[k], ip, n, &ss, NULL); /* with step s1 */
                 if (!k || d0<dmin || d1<dmin) {
                         kmin = k;
                         if (d0<=d1) {
@@ -355,35 +293,30 @@ inline void AdpcmMashChannel(
                 }
         }
         *st = smin;
-#ifdef DEBUG
-        fprintf(stderr,"kmin %d, smin %5d, ",kmin,smin);
-        d=AdpcmMashS(ch, chans, v, iCoef[kmin], ip, n, st, obuff, 1);
-#else
-        d=AdpcmMashS(ch, chans, v, iCoef[kmin], ip, n, st, obuff, 0);
-#endif
+        sox_debug_more("kmin %d, smin %5d, ",kmin,smin);
+        d=AdpcmMashS(ch, chans, v, iCoef[kmin], ip, n, st, obuff);
         obuff[ch] = kmin;
 }
 
 void AdpcmBlockMashI(
-        int chans,          /* total channels */
+        unsigned chans,          /* total channels */
         const SAMPL *ip,    /* ip[n*chans] is interleaved input samples */
         int n,              /* samples to encode PER channel */
         int *st,            /* input/output steps, 16<=st[i] */
         unsigned char *obuff,      /* output buffer[blockAlign]     */
-        int blockAlign,     /* >= 7*chans + chans*(n-2)/2.0    */
-        int opt             /* non-zero allows some cpu-intensive code to improve output */
+        int blockAlign      /* >= 7*chans + chans*(n-2)/2.0    */
 )
 {
-        int ch;
+        unsigned ch;
         unsigned char *p;
 
-        /*fprintf(stderr,"AdpcmMashI(chans %d, ip %p, n %d, st %p, obuff %p, bA %d)\n",
-                                                                 chans, ip, n, st, obuff, blockAlign);*/
+        sox_debug("AdpcmMashI(chans %d, ip %p, n %d, st %p, obuff %p, bA %d)\n",
+                                                                 chans, ip, n, st, obuff, blockAlign);
 
         for (p=obuff+7*chans; p<obuff+blockAlign; p++) *p=0;
 
         for (ch=0; ch<chans; ch++)
-                AdpcmMashChannel(ch, chans, ip, n, st+ch, obuff, opt);
+                AdpcmMashChannel(ch, chans, ip, n, st+ch, obuff);
 }
 
 /*
@@ -394,14 +327,13 @@ void AdpcmBlockMashI(
  *  samplesPerBlock which would go into a block of size blockAlign
  *  Yes, it is confusing usage.
  */
-st_size_t AdpcmSamplesIn(
-        st_size_t dataLen,
-        unsigned short chans,
-        unsigned short blockAlign,
-        unsigned short samplesPerBlock
-)
-{
-        st_size_t m, n;
+sox_size_t AdpcmSamplesIn(
+        sox_size_t dataLen,
+        sox_size_t chans,
+        sox_size_t blockAlign,
+        sox_size_t samplesPerBlock
+){
+        sox_size_t m, n;
 
         if (samplesPerBlock) {
                 n = (dataLen / blockAlign) * samplesPerBlock;
@@ -410,25 +342,24 @@ st_size_t AdpcmSamplesIn(
                 n = 0;
                 m = blockAlign;
         }
-        if (m >= 7*chans) {
+        if (m >= (size_t)(7*chans)) {
                 m -= 7*chans;          /* bytes beyond block-header */
                 m = (2*m)/chans + 2;   /* nibbles/chans + 2 in header */
                 if (samplesPerBlock && m > samplesPerBlock) m = samplesPerBlock;
                 n += m;
         }
         return n;
-        /* wSamplesPerBlock = 2*(wBlockAlign - 7*wChannels)/wChannels + 2; */
 }
 
-st_size_t AdpcmBytesPerBlock(
-        unsigned short chans,
-        unsigned short samplesPerBlock
+sox_size_t AdpcmBytesPerBlock(
+        sox_size_t chans,
+        sox_size_t samplesPerBlock
 )
 {
-        st_size_t n;
+        sox_size_t n;
         n = 7*chans;  /* header */
         if (samplesPerBlock > 2)
-                n += (((st_size_t)samplesPerBlock-2)*chans + 1)/2;
+                n += (((sox_size_t)samplesPerBlock-2)*chans + 1)/2;
         return n;
 }
 
