@@ -11,12 +11,10 @@
  * Cannot handle rate change.
  */
 
-#include "st_i.h"
+#include "sox_i.h"
 
 #include <math.h>   /* exp(), sqrt() */
 
-static st_effect_t st_dcshift_effect;
-
 typedef struct {
     double dcshift; /* DC shift. */
     int uselimiter; /* boolean: are we using the limiter? */
@@ -30,86 +28,65 @@ typedef struct {
 /*
  * Process options: dcshift (double) type (amplitude, power, dB)
  */
-static int st_dcshift_getopts(eff_t effp, int n, char **argv)
+static int sox_dcshift_getopts(sox_effect_t * effp, int n, char **argv)
 {
     dcs_t dcs = (dcs_t) effp->priv;
     dcs->dcshift = 1.0; /* default is no change */
     dcs->uselimiter = 0; /* default is no limiter */
 
     if (n < 1)
-    {
-        st_fail(st_dcshift_effect.usage);
-        return ST_EOF;
-    }
+      return sox_usage(effp);
 
     if (n && (!sscanf(argv[0], "%lf", &dcs->dcshift)))
-    {
-        st_fail(st_dcshift_effect.usage);
-        return ST_EOF;
-    }
+      return sox_usage(effp);
 
     if (n>1)
     {
         if (!sscanf(argv[1], "%lf", &dcs->limitergain))
-        {
-                st_fail(st_dcshift_effect.usage);
-                return ST_EOF;
-        }
+          return sox_usage(effp);
 
         dcs->uselimiter = 1; /* ok, we'll use it */
         /* The following equation is derived so that there is no 
          * discontinuity in output amplitudes */
-        /* and a ST_SAMPLE_MAX input always maps to a ST_SAMPLE_MAX output 
+        /* and a SOX_SAMPLE_MAX input always maps to a SOX_SAMPLE_MAX output 
          * when the limiter is activated. */
         /* (NOTE: There **WILL** be a discontinuity in the slope of the 
          * output amplitudes when using the limiter.) */
-        dcs->limiterthreshhold = ST_SAMPLE_MAX * (1.0 - (fabs(dcs->dcshift) - dcs->limitergain));
+        dcs->limiterthreshhold = SOX_SAMPLE_MAX * (1.0 - (fabs(dcs->dcshift) - dcs->limitergain));
     }
 
-    return ST_SUCCESS;
+    return SOX_SUCCESS;
 }
 
 /*
  * Start processing
  */
-static int st_dcshift_start(eff_t effp)
+static int sox_dcshift_start(sox_effect_t * effp)
 {
     dcs_t dcs = (dcs_t) effp->priv;
 
     if (dcs->dcshift == 0)
-      return ST_EFF_NULL;
-
-    if (effp->outinfo.channels != effp->ininfo.channels) {
-        st_fail("DCSHIFT cannot handle different channels (in=%d, out=%d)"
-             " use avg or pan", effp->ininfo.channels, effp->outinfo.channels);
-        return ST_EOF;
-    }
-
-    if (effp->outinfo.rate != effp->ininfo.rate) {
-        st_fail("DCSHIFT cannot handle different rates (in=%ld, out=%ld)"
-             " use resample or rate", effp->ininfo.rate, effp->outinfo.rate);
-        return ST_EOF;
-    }
+      return SOX_EFF_NULL;
 
     dcs->clipped = 0;
     dcs->limited = 0;
     dcs->totalprocessed = 0;
 
-    return ST_SUCCESS;
+    return SOX_SUCCESS;
 }
 
 /*
  * Process data.
  */
-static int st_dcshift_flow(eff_t effp, const st_sample_t *ibuf, st_sample_t *obuf, 
-                    st_size_t *isamp, st_size_t *osamp)
+static int sox_dcshift_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *obuf, 
+                    sox_size_t *isamp, sox_size_t *osamp)
 {
     dcs_t dcs = (dcs_t) effp->priv;
     double dcshift = dcs->dcshift;
     double limitergain = dcs->limitergain;
     double limiterthreshhold = dcs->limiterthreshhold;
     double sample;
-    st_size_t len;
+    sox_size_t len;
 
     len = min(*osamp, *isamp);
 
@@ -126,26 +103,26 @@ static int st_dcshift_flow(eff_t effp, const st_sample_t *ibuf, st_sample_t *obu
 
                 if (sample > limiterthreshhold && dcshift > 0)
                 {
-                        sample =  (sample - limiterthreshhold) * limitergain / (ST_SAMPLE_MAX - limiterthreshhold) + limiterthreshhold + dcshift;
+                        sample =  (sample - limiterthreshhold) * limitergain / (SOX_SAMPLE_MAX - limiterthreshhold) + limiterthreshhold + dcshift;
                         dcs->limited++;
                 }
                 else if (sample < -limiterthreshhold && dcshift < 0)
                 {
-                        /* Note this should really be ST_SAMPLE_MIN but
+                        /* Note this should really be SOX_SAMPLE_MIN but
                          * the clip() below will take care of the overflow.
                          */
-                        sample =  (sample + limiterthreshhold) * limitergain / (ST_SAMPLE_MAX - limiterthreshhold) - limiterthreshhold + dcshift;
+                        sample =  (sample + limiterthreshhold) * limitergain / (SOX_SAMPLE_MAX - limiterthreshhold) - limiterthreshhold + dcshift;
                         dcs->limited++;
                 }
                 else
                 {
-                        /* Note this should consider ST_SAMPLE_MIN but
+                        /* Note this should consider SOX_SAMPLE_MIN but
                          * the clip() below will take care of the overflow.
                          */
-                        sample = dcshift * ST_SAMPLE_MAX + sample;
+                        sample = dcshift * SOX_SAMPLE_MAX + sample;
                 }
 
-                ST_SAMPLE_CLIP_COUNT(sample, dcs->clipped);
+                SOX_SAMPLE_CLIP_COUNT(sample, dcs->clipped);
                 *obuf++ = sample;
             }
     }
@@ -156,58 +133,58 @@ static int st_dcshift_flow(eff_t effp, const st_sample_t *ibuf, st_sample_t *obu
         {
                 double f;
 
-                f = dcshift * ST_SAMPLE_MAX + *ibuf++;
-                ST_SAMPLE_CLIP_COUNT(f, dcs->clipped);
+                f = dcshift * SOX_SAMPLE_MAX + *ibuf++;
+                SOX_SAMPLE_CLIP_COUNT(f, dcs->clipped);
                 *obuf++ = f;
         }
     }
-    return ST_SUCCESS;
+    return SOX_SUCCESS;
 }
 
 /*
  * Do anything required when you stop reading samples.
  * Don't close input file!
  */
-static int st_dcshift_stop(eff_t effp)
+static int sox_dcshift_stop(sox_effect_t * effp)
 {
     dcs_t dcs = (dcs_t) effp->priv;
 
     if (dcs->limited)
     {
-        st_warn("DCSHIFT limited %d values (%d percent).",
+        sox_warn("DCSHIFT limited %d values (%d percent).",
              dcs->limited, (int) (dcs->limited * 100.0 / dcs->totalprocessed));
     }
     if (dcs->clipped)
     {
         if (dcs->dcshift > 0)
         {
-             st_warn("DCSHIFT clipped %d values, dcshift=%f too high...",
+             sox_warn("DCSHIFT clipped %d values, dcshift=%f too high...",
                   dcs->clipped, dcs->dcshift);
         }
         else
         {
-             st_warn("DCSHIFT clipped %d values, dcshift=%f too low...",
+             sox_warn("DCSHIFT clipped %d values, dcshift=%f too low...",
                   dcs->clipped, dcs->dcshift);
         }
     }
-    return ST_SUCCESS;
+    return SOX_SUCCESS;
 }
 
-static st_effect_t st_dcshift_effect = {
+static sox_effect_handler_t sox_dcshift_effect = {
    "dcshift",
-   "Usage: dcshift shift [ limitergain ]\n"
+   "shift [ limitergain ]\n"
    "       The peak limiter has a gain much less than 1.0 (ie 0.05 or 0.02) which is only\n"
    "       used on peaks to prevent clipping. (default is no limiter)",
-   ST_EFF_MCHAN,
-   st_dcshift_getopts,
-   st_dcshift_start,
-   st_dcshift_flow,
-   st_effect_nothing_drain,
-   st_dcshift_stop,
-  st_effect_nothing
+   SOX_EFF_MCHAN,
+   sox_dcshift_getopts,
+   sox_dcshift_start,
+   sox_dcshift_flow,
+   NULL,
+   sox_dcshift_stop,
+  NULL
 };
 
-const st_effect_t *st_dcshift_effect_fn(void)
+const sox_effect_handler_t *sox_dcshift_effect_fn(void)
 {
-    return &st_dcshift_effect;
+    return &sox_dcshift_effect;
 }
