@@ -1,4 +1,4 @@
-#include "stconfig.h"
+#include "soxconfig.h"
 #ifndef HAVE_GETOPT_LONG
 
 /* Getopt for GNU.
@@ -30,9 +30,11 @@
 # define _NO_PROTO
 #endif
 
+#if 0
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
+#endif
 
 #if !defined __STDC__ || !__STDC__
 /* This is a separate conditional since some stdc systems
@@ -262,7 +264,7 @@ static int last_nonopt;
 #ifdef _LIBC
 /* Stored original parameters.
    XXX This is no good solution.  We should rather copy the args so
-   that we can compare them later.  But we must not use malloc(3).  */
+   that we can compare them later.  But we must not use xmalloc(3).  */
 extern int __libc_argc;
 extern char **__libc_argv;
 
@@ -327,7 +329,7 @@ exchange (argv)
     {
       /* We must extend the array.  The user plays games with us and
          presents new arguments.  */
-      char *new_str = malloc (top + 1);
+      char *new_str = xmalloc (top + 1);
       if (new_str == NULL)
         nonoption_flags_len = nonoption_flags_max_len = 0;
       else
@@ -439,7 +441,7 @@ _getopt_initialize (argc, argv, optstring)
               if (nonoption_flags_max_len < argc)
                 nonoption_flags_max_len = argc;
               __getopt_nonoption_flags =
-                (char *) malloc (nonoption_flags_max_len);
+                (char *) xmalloc (nonoption_flags_max_len);
               if (__getopt_nonoption_flags == NULL)
                 nonoption_flags_max_len = -1;
               else
