@@ -1,4 +1,4 @@
-#include "stconfig.h"
+#include "soxconfig.h"
 #ifndef HAVE_GETOPT_LONG
 /* getopt_long and getopt_long_only entry points for GNU getopt.
    Copyright (C) 1987,88,89,90,91,92,93,94,96,97,98
