@@ -19,8 +19,6 @@
 #include <string.h>
 #include <errno.h>
 
-static st_effect_t st_noiseprof_effect;
-
 typedef struct chandata {
     float *sum;
     int   *profilecount;
@@ -33,64 +31,63 @@ typedef struct profdata {
     FILE* output_file;
 
     chandata_t *chandata;
-    st_size_t bufdata;
+    sox_size_t bufdata;
 } * profdata_t;
 
 /*
- * Get the filename, if any. We don't open it until st_noiseprof_start.
+ * Get the filename, if any. We don't open it until sox_noiseprof_start.
  */
-int st_noiseprof_getopts(eff_t effp, int n, char **argv) 
+static int sox_noiseprof_getopts(sox_effect_t * effp, int n, char **argv) 
 {
     profdata_t data = (profdata_t) effp->priv;
 
     if (n == 1) {
         data->output_filename = argv[0];
-    } else if (n > 1) {
-        st_fail(st_noiseprof_effect.usage);
-        return (ST_EOF);
-    }
+    } else if (n > 1)
+      return sox_usage(effp);
 
-    return (ST_SUCCESS);
+    return (SOX_SUCCESS);
 }
 
 /*
  * Prepare processing.
  * Do all initializations.
  */
-int st_noiseprof_start(eff_t effp)
+static int sox_noiseprof_start(sox_effect_t * effp)
 {
-    profdata_t data = (profdata_t) effp->priv;
-    int channels = effp->ininfo.channels;
-    int i;
+  profdata_t data = (profdata_t) effp->priv;
+  unsigned channels = effp->ininfo.channels;
+  unsigned i;
    
-    if (data->output_filename != NULL) {
-        data->output_file = fopen(data->output_filename, "w");
-        if (data->output_file == NULL) {
-            st_fail("Couldn't open output file %s: %s",
-                    data->output_filename, strerror(errno));            
-        }
-    } else {
-        /* FIXME: We should detect output to stdout, and redirect to stderr. */
-        data->output_file = stderr;
+  /* Note: don't fall back to stderr if stdout is unavailable
+   * since we already use stderr for diagnostics. */
+  if (!data->output_filename || !strcmp(data->output_filename, "-")) {
+    if (effp->global_info->global_info->stdout_in_use_by) {
+      sox_fail("stdout already in use by '%s'", effp->global_info->global_info->stdout_in_use_by);
+      return SOX_EOF;
     }
+    effp->global_info->global_info->stdout_in_use_by = effp->handler.name;
+    data->output_file = stdout;
+  }
+  else if ((data->output_file = fopen(data->output_filename, "w")) == NULL) {
+    sox_fail("Couldn't open profile file %s: %s", data->output_filename, strerror(errno));
+    return SOX_EOF;
+  }
 
-    data->chandata = (chandata_t*)calloc(channels, sizeof(*(data->chandata)));
-    for (i = 0; i < channels; i ++) {
-        data->chandata[i].sum          =
-            (float*)calloc(FREQCOUNT, sizeof(float));
-        data->chandata[i].profilecount =
-            (int*)calloc(FREQCOUNT, sizeof(int));
-        data->chandata[i].window       =
-            (float*)calloc(WINDOWSIZE, sizeof(float));
-    }
-    data->bufdata = 0;
-    return (ST_SUCCESS);
+  data->chandata = (chandata_t*)xcalloc(channels, sizeof(*(data->chandata)));
+  data->bufdata = 0;
+  for (i = 0; i < channels; i ++) {
+    data->chandata[i].sum = (float*)xcalloc(FREQCOUNT, sizeof(float));
+    data->chandata[i].profilecount = (int*)xcalloc(FREQCOUNT, sizeof(int));
+    data->chandata[i].window = (float*)xcalloc(WINDOWSIZE, sizeof(float));
+  }
+
+  return SOX_SUCCESS;
 }
 
 /* Collect statistics from the complete window on channel chan. */
-static void collect_data(profdata_t data, chandata_t* chan) {
-    float *out = (float*)calloc(FREQCOUNT, sizeof(float));
-
+static void collect_data(chandata_t* chan) {
+    float *out = (float*)xcalloc(FREQCOUNT, sizeof(float));
     int i;
 
     PowerSpectrum(WINDOWSIZE, chan->window, out);
@@ -109,16 +106,17 @@ static void collect_data(profdata_t data, chandata_t* chan) {
 /*
  * Grab what we can from ibuf, and process if we have a whole window.
  */
-int st_noiseprof_flow(eff_t effp, st_sample_t *ibuf, st_sample_t *obuf, 
-                    st_size_t *isamp, st_size_t *osamp)
+static int sox_noiseprof_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *obuf, 
+                    sox_size_t *isamp, sox_size_t *osamp)
 {
     profdata_t data = (profdata_t) effp->priv;
-    int samp = min(*isamp, *osamp);
-    int tracks = effp->ininfo.channels;
-    int track_samples = samp / tracks;
+    sox_size_t samp = min(*isamp, *osamp);
+    sox_size_t tracks = effp->ininfo.channels;
+    sox_size_t track_samples = samp / tracks;
     int ncopy = 0;
-    int i;
+    sox_size_t i;
 
+    /* FIXME: Make this automatic for all effects */
     assert(effp->ininfo.channels == effp->outinfo.channels);
 
     /* How many samples per track to analyze? */
@@ -130,11 +128,10 @@ int st_noiseprof_flow(eff_t effp, st_sample_t *ibuf, st_sample_t *obuf,
         int j;
         for (j = 0; j < ncopy; j ++) {
             chan->window[j+data->bufdata] =
-                ST_SAMPLE_TO_FLOAT_DWORD(ibuf[i+j*tracks]);
-        }
-        if (ncopy + data->bufdata == WINDOWSIZE) {
-            collect_data(data, chan);
+                SOX_SAMPLE_TO_FLOAT_32BIT(ibuf[i+j*tracks], effp->clips);
         }
+        if (ncopy + data->bufdata == WINDOWSIZE)
+            collect_data(chan);
     }
 
     data->bufdata += ncopy;
@@ -145,14 +142,14 @@ int st_noiseprof_flow(eff_t effp, st_sample_t *ibuf, st_sample_t *obuf,
     memcpy(obuf, ibuf, ncopy*tracks);
     *isamp = *osamp = ncopy*tracks;
 
-    return (ST_SUCCESS);
+    return (SOX_SUCCESS);
 }
 
 /*
  * Finish off the last window.
  */
 
-int st_noiseprof_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
+static int sox_noiseprof_drain(sox_effect_t * effp, sox_ssample_t *obuf UNUSED, sox_size_t *osamp)
 {
     profdata_t data = (profdata_t) effp->priv;
     int tracks = effp->ininfo.channels;
@@ -161,7 +158,7 @@ int st_noiseprof_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
     *osamp = 0;
 
     if (data->bufdata == 0) {
-        return ST_EOF;
+        return SOX_EOF;
     }
 
     for (i = 0; i < tracks; i ++) {
@@ -169,22 +166,22 @@ int st_noiseprof_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
         for (j = data->bufdata+1; j < WINDOWSIZE; j ++) {
             data->chandata[i].window[j] = 0;
         }
-        collect_data(data, &(data->chandata[i]));
+        collect_data(&(data->chandata[i]));
     }
 
     if (data->bufdata == WINDOWSIZE || data->bufdata == 0)
-        return ST_EOF;
+        return SOX_EOF;
     else
-        return ST_SUCCESS;
+        return SOX_SUCCESS;
 }
 
 /*
  * Print profile and clean up.
  */
-int st_noiseprof_stop(eff_t effp)
+static int sox_noiseprof_stop(sox_effect_t * effp)
 {
     profdata_t data = (profdata_t) effp->priv;
-    int i;
+    sox_size_t i;
 
     for (i = 0; i < effp->ininfo.channels; i ++) {
         int j;
@@ -193,8 +190,9 @@ int st_noiseprof_stop(eff_t effp)
         fprintf(data->output_file, "Channel %d: ", i);
 
         for (j = 0; j < FREQCOUNT; j ++) {
-            fprintf(data->output_file, "%s%f", j == 0 ? "" : ", ",
-                    chan->sum[j] / chan->profilecount[j]);
+            double r = chan->profilecount[j] != 0 ? 
+                    chan->sum[j] / chan->profilecount[j] : 0;
+            fprintf(data->output_file, "%s%f", j == 0 ? "" : ", ", r);
         }
         fprintf(data->output_file, "\n");
 
@@ -204,30 +202,25 @@ int st_noiseprof_stop(eff_t effp)
 
     free(data->chandata);
 
-    if (data->output_file != stderr && data->output_file != stdout) {
+    if (data->output_file != stdout)
         fclose(data->output_file);
-    }       
     
-    return (ST_SUCCESS);
+    return (SOX_SUCCESS);
 }
 
-static st_effect_t st_noiseprof_effect = {
+static sox_effect_handler_t sox_noiseprof_effect = {
   "noiseprof",
-  "Usage: noiseprof [filename]",
-  ST_EFF_MCHAN | ST_EFF_REPORT,
-  st_noiseprof_getopts,
-  st_noiseprof_start,
-  st_noiseprof_flow,
-  st_noiseprof_drain,
-  st_noiseprof_stop
+  "[profile-file]",
+  SOX_EFF_MCHAN,
+  sox_noiseprof_getopts,
+  sox_noiseprof_start,
+  sox_noiseprof_flow,
+  sox_noiseprof_drain,
+  sox_noiseprof_stop,
+  NULL
 };
 
-const st_effect_t *st_noiseprof_effect_fn(void)
+const sox_effect_handler_t *sox_noiseprof_effect_fn(void)
 {
-    return &st_noiseprof_effect;
+    return &sox_noiseprof_effect;
 }
-
-/* For Emacs:
-   Local Variables:
-   c-basic-offset: 4
-*/
