@@ -17,110 +17,107 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "st_i.h"
+#include "sox_i.h"
 
 #include <stdio.h>
 #include <errno.h>
 #include <string.h>
-
-static st_effect_t st_repeat_effect;
+#include <sys/types.h> /* for off_t on OS/2 and possibly others */
 
 typedef struct repeatstuff {
         FILE *fp;
         int first_drain;
-        st_size_t total;
-        st_size_t remaining;
+        sox_size_t total;
+        sox_size_t remaining;
         int repeats;
 } *repeat_t;
 
-static int st_repeat_getopts(eff_t effp, int n, char **argv)
+static int sox_repeat_getopts(sox_effect_t * effp, int n, char **argv)
 {
         repeat_t repeat = (repeat_t)effp->priv;
 
-        if (n != 1) {
-                st_fail(st_repeat_effect.usage);
-                return (ST_EOF);
-        }
+        if (n != 1)
+          return sox_usage(effp);
 
         if (!(sscanf(argv[0], "%i", &repeat->repeats))) {
-                st_fail("repeat: could not parse repeat parameter");
-                return (ST_EOF);
+                sox_fail("could not parse repeat parameter");
+                return (SOX_EOF);
         }
 
         if (repeat->repeats < 0) {
-                st_fail("repeat: repeat parameter must be positive");
-                return (ST_EOF);
+                sox_fail("repeat parameter must be positive");
+                return (SOX_EOF);
         }
 
-        return (ST_SUCCESS);
+        return (SOX_SUCCESS);
 }
 
-static int st_repeat_start(eff_t effp)
+static int sox_repeat_start(sox_effect_t * effp)
 {
         repeat_t repeat = (repeat_t)effp->priv;
 
         if (repeat->repeats == 0)
-          return ST_EFF_NULL;
+          return SOX_EFF_NULL;
 
         if ((repeat->fp = tmpfile()) == NULL) {
-                st_fail("repeat: could not create temporary file");
-                return (ST_EOF);
+                sox_fail("could not create temporary file");
+                return (SOX_EOF);
         }
 
         repeat->first_drain = 1;
 
-        return (ST_SUCCESS);
+        return (SOX_SUCCESS);
 }
 
-static int st_repeat_flow(eff_t effp, const st_sample_t *ibuf, st_sample_t *obuf UNUSED,
-                st_size_t *isamp, st_size_t *osamp)
+static int sox_repeat_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *obuf UNUSED,
+                sox_size_t *isamp, sox_size_t *osamp)
 {
         repeat_t repeat = (repeat_t)effp->priv;
 
-        if (fwrite((char *)ibuf, sizeof(st_sample_t), *isamp, repeat->fp) !=
+        if (fwrite((char *)ibuf, sizeof(sox_ssample_t), *isamp, repeat->fp) !=
                         *isamp) {
-                st_fail("repeat: write error on temporary file");
-                return (ST_EOF);
+                sox_fail("write error on temporary file");
+                return (SOX_EOF);
         }
 
         *osamp = 0;
 
-        return (ST_SUCCESS);
+        return (SOX_SUCCESS);
 }
 
-static int st_repeat_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
+static int sox_repeat_drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t *osamp)
 {
         size_t read = 0;
-        st_sample_t *buf;
-        st_size_t samp;
-        st_size_t done;
+        sox_ssample_t *buf;
+        sox_size_t samp;
+        sox_size_t done;
 
         repeat_t repeat = (repeat_t)effp->priv;
 
         if (repeat->first_drain == 1) {
                 repeat->first_drain = 0;
 
-                fseeko(repeat->fp, 0, SEEK_END);
+                fseeko(repeat->fp, (off_t)0, SEEK_END);
                 repeat->total = ftello(repeat->fp);
 
-                if ((repeat->total % sizeof(st_sample_t)) != 0) {
-                        st_fail("repeat: corrupted temporary file");
-                        return (ST_EOF);
+                if ((repeat->total % sizeof(sox_ssample_t)) != 0) {
+                        sox_fail("corrupted temporary file");
+                        return (SOX_EOF);
                 }
 
-                repeat->total /= sizeof(st_sample_t);
+                repeat->total /= sizeof(sox_ssample_t);
                 repeat->remaining = repeat->total;
 
-                fseeko(repeat->fp, 0, SEEK_SET);
+                fseeko(repeat->fp, (off_t)0, SEEK_SET);
         }
 
         if (repeat->remaining == 0) {
                 if (repeat->repeats == 0) {
                         *osamp = 0;
-                        return (ST_EOF);
+                        return (SOX_EOF);
                 } else {
                         repeat->repeats--;
-                        fseeko(repeat->fp, 0, SEEK_SET);
+                        fseeko(repeat->fp, (off_t)0, SEEK_SET);
                         repeat->remaining = repeat->total;
                 }
         }
@@ -128,12 +125,12 @@ static int st_repeat_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
                 buf = obuf;
                 samp = repeat->remaining;
 
-                read = fread((char *)buf, sizeof(st_sample_t), samp,
+                read = fread((char *)buf, sizeof(sox_ssample_t), samp,
                                 repeat->fp);
                 if (read != samp) {
                         perror(strerror(errno));
-                        st_fail("repeat: read error on temporary file");
-                        return(ST_EOF);
+                        sox_fail("read error on temporary file");
+                        return(SOX_EOF);
                 }
 
                 done = samp;
@@ -142,7 +139,7 @@ static int st_repeat_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
 
                 while (repeat->repeats > 0) {
                         repeat->repeats--;
-                        fseeko(repeat->fp, 0, SEEK_SET);
+                        fseeko(repeat->fp, (off_t)0, SEEK_SET);
 
                         if (repeat->total >= *osamp - done) {
                                 samp = *osamp - done;
@@ -154,13 +151,13 @@ static int st_repeat_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
 
                         repeat->remaining = repeat->total - samp;
 
-                        read = fread((char *)buf, sizeof(st_sample_t), samp,
+                        read = fread((char *)buf, sizeof(sox_ssample_t), samp,
                                         repeat->fp);
                         if (read != samp) {
                                 perror(strerror(errno));
-                                st_fail("repeat2: read error on temporary "
+                                sox_fail("repeat2: read error on temporary "
                                                 "file\n");
-                                return(ST_EOF);
+                                return(SOX_EOF);
                         }
 
                         done += samp;
@@ -170,44 +167,44 @@ static int st_repeat_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
                 *osamp = done;
         }
         else {
-                read = fread((char *)obuf, sizeof(st_sample_t), *osamp,
+                read = fread((char *)obuf, sizeof(sox_ssample_t), *osamp,
                                 repeat->fp);
                 if (read != *osamp) {
                         perror(strerror(errno));
-                        st_fail("repeat3: read error on temporary file");
-                        return(ST_EOF);
+                        sox_fail("repeat3: read error on temporary file");
+                        return(SOX_EOF);
                 }
                 repeat->remaining -= *osamp;
         }
 
         if (repeat->remaining == 0)
-            return ST_EOF;
+            return SOX_EOF;
         else
-            return ST_SUCCESS;
+            return SOX_SUCCESS;
 }
 
-static int st_repeat_stop(eff_t effp)
+static int sox_repeat_stop(sox_effect_t * effp)
 {
         repeat_t repeat = (repeat_t)effp->priv;
 
         fclose(repeat->fp);
 
-        return (ST_SUCCESS);
+        return (SOX_SUCCESS);
 }
 
-static st_effect_t st_repeat_effect = {
+static sox_effect_handler_t sox_repeat_effect = {
   "repeat",
-  "Usage: repeat count",
-  0,
-  st_repeat_getopts,
-  st_repeat_start,
-  st_repeat_flow,
-  st_repeat_drain,
-  st_repeat_stop,
-  st_effect_nothing
+  "count",
+  SOX_EFF_MCHAN | SOX_EFF_LENGTH,
+  sox_repeat_getopts,
+  sox_repeat_start,
+  sox_repeat_flow,
+  sox_repeat_drain,
+  sox_repeat_stop,
+  NULL
 };
 
-const st_effect_t *st_repeat_effect_fn(void)
+const sox_effect_handler_t *sox_repeat_effect_fn(void)
 {
-    return &st_repeat_effect;
+    return &sox_repeat_effect;
 }
