@@ -10,27 +10,13 @@
  * when it sees a specified count of samples below a given threshold
  * (all channels).
  * It may also be used to delete samples anywhere in a sound file.
- * Theshold's can be given as either a percentage or in decibels.
+ * Thesholds can be given as either a percentage or in decibels.
  */
 
 
 #include <string.h>
 #include <math.h>
-#include "st_i.h"
-
-static st_effect_t st_silence_effect;
-
-#ifndef TRUE
-#define TRUE 1
-#endif
-
-#ifndef FALSE
-#define FALSE 0
-#endif
-
-#ifndef min
-#define min(s1,s2) ((s1)<(s2)?(s1):(s2))
-#endif
+#include "sox_i.h"
 
 /* Private data for silence effect. */
 
@@ -45,39 +31,41 @@ typedef struct silencestuff
     char        start;
     int         start_periods;
     char        *start_duration_str;
-    st_size_t   start_duration;
+    sox_size_t   start_duration;
     double      start_threshold;
     char        start_unit; /* "d" for decibels or "%" for percent. */
     int         restart;
 
-    st_sample_t *start_holdoff;
-    st_size_t   start_holdoff_offset;
-    st_size_t   start_holdoff_end;
+    sox_ssample_t *start_holdoff;
+    sox_size_t   start_holdoff_offset;
+    sox_size_t   start_holdoff_end;
     int         start_found_periods;
 
     char        stop;
     int         stop_periods;
     char        *stop_duration_str;
-    st_size_t   stop_duration;
+    sox_size_t   stop_duration;
     double      stop_threshold;
     char        stop_unit;
 
-    st_sample_t *stop_holdoff;
-    st_size_t   stop_holdoff_offset;
-    st_size_t   stop_holdoff_end;
+    sox_ssample_t *stop_holdoff;
+    sox_size_t   stop_holdoff_offset;
+    sox_size_t   stop_holdoff_end;
     int         stop_found_periods;
 
     double      *window;
     double      *window_current;
     double      *window_end;
-    st_size_t   window_size;
+    sox_size_t   window_size;
     double      rms_sum;
 
+    char        leave_silence;
+
     /* State Machine */
     char        mode;
 } *silence_t;
 
-static void clear_rms(eff_t effp)
+static void clear_rms(sox_effect_t * effp)
 
 {
     silence_t silence = (silence_t) effp->priv;
@@ -90,68 +78,57 @@ static void clear_rms(eff_t effp)
     silence->rms_sum = 0;
 }
 
-int st_silence_getopts(eff_t effp, int n, char **argv)
+static int sox_silence_getopts(sox_effect_t * effp, int n, char **argv)
 {
     silence_t   silence = (silence_t) effp->priv;
     int parse_count;
 
-    if (n < 1)
+    /* check for option switches */
+    silence->leave_silence = sox_false;
+    if (n > 0)
     {
-        st_fail(st_silence_effect.usage);
-        return (ST_EOF);
+        if (!strcmp("-l", *argv)) {
+            n--; argv++;
+            silence->leave_silence = sox_true;
+        }
     }
 
+    if (n < 1)
+      return sox_usage(effp);
+
     /* Parse data related to trimming front side */
-    silence->start = FALSE;
+    silence->start = sox_false;
     if (sscanf(argv[0], "%d", &silence->start_periods) != 1)
-    {
-        st_fail(st_silence_effect.usage);
-        return(ST_EOF);
-    }
+      return sox_usage(effp);
     if (silence->start_periods < 0)
     {
-        st_fail("Periods must not be negative");
-        return(ST_EOF);
+        sox_fail("Periods must not be negative");
+        return(SOX_EOF);
     }
     argv++;
     n--;
 
     if (silence->start_periods > 0)
     {
-        silence->start = TRUE;
+        silence->start = sox_true;
         if (n < 2)
-        {
-            st_fail(st_silence_effect.usage);
-            return ST_EOF;
-        }
+          return sox_usage(effp);
 
         /* We do not know the sample rate so we can not fully
          * parse the duration info yet.  So save argument off
          * for future processing.
          */
-        silence->start_duration_str = (char *)malloc(strlen(argv[0])+1);
-        if (!silence->start_duration_str)
-        {
-            st_fail("Could not allocate memory");
-            return(ST_EOF);
-        }
+        silence->start_duration_str = (char *)xmalloc(strlen(argv[0])+1);
         strcpy(silence->start_duration_str,argv[0]);
         /* Perform a fake parse to do error checking */
-        if (st_parsesamples(0,silence->start_duration_str,
-                    &silence->start_duration,'s') !=
-                ST_SUCCESS)
-        {
-            st_fail(st_silence_effect.usage);
-            return(ST_EOF);
-        }
+        if (sox_parsesamples(0,silence->start_duration_str,
+                    &silence->start_duration,'s') == NULL)
+          return sox_usage(effp);
 
         parse_count = sscanf(argv[1], "%lf%c", &silence->start_threshold, 
                 &silence->start_unit);
         if (parse_count < 1)
-        {
-            st_fail(st_silence_effect.usage);
-            return ST_EOF;
-        }
+          return sox_usage(effp);
         else if (parse_count < 2)
             silence->start_unit = '%';
 
@@ -159,20 +136,14 @@ int st_silence_getopts(eff_t effp, int n, char **argv)
         n--; n--;
     }
 
-    silence->stop = FALSE;
+    silence->stop = sox_false;
     /* Parse data needed for trimming of backside */
     if (n > 0)
     {
         if (n < 3)
-        {
-            st_fail(st_silence_effect.usage);
-            return ST_EOF;
-        }
+          return sox_usage(effp);
         if (sscanf(argv[0], "%d", &silence->stop_periods) != 1)
-        {
-            st_fail(st_silence_effect.usage);
-            return ST_EOF;
-        }
+          return sox_usage(effp);
         if (silence->stop_periods < 0)
         {
             silence->stop_periods = -silence->stop_periods;
@@ -180,7 +151,7 @@ int st_silence_getopts(eff_t effp, int n, char **argv)
         }
         else
             silence->restart = 0;
-        silence->stop = TRUE;
+        silence->stop = sox_true;
         argv++;
         n--;
 
@@ -188,29 +159,17 @@ int st_silence_getopts(eff_t effp, int n, char **argv)
          * parse the duration info yet.  So save argument off
          * for future processing.
          */
-        silence->stop_duration_str = (char *)malloc(strlen(argv[0])+1);
-        if (!silence->stop_duration_str)
-        {
-            st_fail("Could not allocate memory");
-            return(ST_EOF);
-        }
+        silence->stop_duration_str = (char *)xmalloc(strlen(argv[0])+1);
         strcpy(silence->stop_duration_str,argv[0]);
         /* Perform a fake parse to do error checking */
-        if (st_parsesamples(0,silence->stop_duration_str,
-                    &silence->stop_duration,'s') !=
-                ST_SUCCESS)
-        {
-            st_fail(st_silence_effect.usage);
-            return(ST_EOF);
-        }
+        if (sox_parsesamples(0,silence->stop_duration_str,
+                    &silence->stop_duration,'s') == NULL)
+          return sox_usage(effp);
 
         parse_count = sscanf(argv[1], "%lf%c", &silence->stop_threshold, 
                              &silence->stop_unit);
         if (parse_count < 1)
-        {
-            st_fail(st_silence_effect.usage);
-            return ST_EOF;
-        }
+          return sox_usage(effp);
         else if (parse_count < 2)
             silence->stop_unit = '%';
 
@@ -223,20 +182,19 @@ int st_silence_getopts(eff_t effp, int n, char **argv)
     {
         if ((silence->start_unit != '%') && (silence->start_unit != 'd'))
         {
-            st_fail("Invalid unit specified");
-            st_fail(st_silence_effect.usage);
-            return(ST_EOF);
+            sox_fail("Invalid unit specified");
+            return sox_usage(effp);
         }
         if ((silence->start_unit == '%') && ((silence->start_threshold < 0.0)
             || (silence->start_threshold > 100.0)))
         {
-            st_fail("silence threshold should be between 0.0 and 100.0 %%");
-            return (ST_EOF);
+            sox_fail("silence threshold should be between 0.0 and 100.0 %%");
+            return (SOX_EOF);
         }
         if ((silence->start_unit == 'd') && (silence->start_threshold >= 0.0))
         {
-            st_fail("silence threshold should be less than 0.0 dB");
-            return(ST_EOF);
+            sox_fail("silence threshold should be less than 0.0 dB");
+            return(SOX_EOF);
         }
     }
 
@@ -244,25 +202,25 @@ int st_silence_getopts(eff_t effp, int n, char **argv)
     {
         if ((silence->stop_unit != '%') && (silence->stop_unit != 'd'))
         {
-            st_fail("Invalid unit specified");
-            return(ST_EOF);
+            sox_fail("Invalid unit specified");
+            return(SOX_EOF);
         }
         if ((silence->stop_unit == '%') && ((silence->stop_threshold < 0.0) || 
                     (silence->stop_threshold > 100.0)))
         {
-            st_fail("silence threshold should be between 0.0 and 100.0 %%");
-            return (ST_EOF);
+            sox_fail("silence threshold should be between 0.0 and 100.0 %%");
+            return (SOX_EOF);
         }
         if ((silence->stop_unit == 'd') && (silence->stop_threshold >= 0.0))
         {
-            st_fail("silence threshold should be less than 0.0 dB");
-            return(ST_EOF);
+            sox_fail("silence threshold should be less than 0.0 dB");
+            return(SOX_EOF);
         }
     }
-    return(ST_SUCCESS);
+    return(SOX_SUCCESS);
 }
 
-int st_silence_start(eff_t effp)
+static int sox_silence_start(sox_effect_t * effp)
 {
         silence_t       silence = (silence_t) effp->priv;
 
@@ -272,37 +230,23 @@ int st_silence_start(eff_t effp)
          */
         silence->window_size = (effp->ininfo.rate / 50) * 
                                effp->ininfo.channels;
-        silence->window = (double *)malloc(silence->window_size *
+        silence->window = (double *)xmalloc(silence->window_size *
                                            sizeof(double));
 
-        if (!silence->window)
-        {
-            st_fail("Unable to allocate memory");
-            return(ST_EOF);
-        }
-
         clear_rms(effp);
 
-        /* Now that we now sample rate, reparse duration. */
+        /* Now that we know sample rate, reparse duration. */
         if (silence->start)
         {
-            if (st_parsesamples(effp->ininfo.rate, silence->start_duration_str,
-                                &silence->start_duration, 's') !=
-                    ST_SUCCESS)
-            {
-                st_fail(st_silence_effect.usage);
-                return(ST_EOF);
-            }
+            if (sox_parsesamples(effp->ininfo.rate, silence->start_duration_str,
+                                &silence->start_duration, 's') == NULL)
+              return sox_usage(effp);
         }
         if (silence->stop)
         {
-            if (st_parsesamples(effp->ininfo.rate,silence->stop_duration_str,
-                                &silence->stop_duration,'s') !=
-                    ST_SUCCESS)
-            {
-                st_fail(st_silence_effect.usage);
-                return(ST_EOF);
-            }
+            if (sox_parsesamples(effp->ininfo.rate,silence->stop_duration_str,
+                                &silence->stop_duration,'s') == NULL)
+              return sox_usage(effp);
         }
 
         if (silence->start)
@@ -310,49 +254,44 @@ int st_silence_start(eff_t effp)
         else
             silence->mode = SILENCE_COPY;
 
-        silence->start_holdoff = (st_sample_t *)malloc(sizeof(st_sample_t)*silence->start_duration);
-        if (!silence->start_holdoff)
-        {
-            st_fail("Could not allocate memory");
-            return(ST_EOF);
-        }
+        silence->start_holdoff = (sox_ssample_t *)xmalloc(sizeof(sox_ssample_t)*silence->start_duration);
         silence->start_holdoff_offset = 0;
         silence->start_holdoff_end = 0;
         silence->start_found_periods = 0;
 
-        silence->stop_holdoff = (st_sample_t *)malloc(sizeof(st_sample_t)*silence->stop_duration);
-        if (!silence->stop_holdoff)
-        {
-            st_fail("Could not allocate memory");
-            return(ST_EOF);
-        }
+        silence->stop_holdoff = (sox_ssample_t *)xmalloc(sizeof(sox_ssample_t)*silence->stop_duration);
         silence->stop_holdoff_offset = 0;
         silence->stop_holdoff_end = 0;
         silence->stop_found_periods = 0;
 
-        return(ST_SUCCESS);
+        return(SOX_SUCCESS);
 }
 
-int aboveThreshold(eff_t effp, st_sample_t value, double threshold, char unit)
+static int aboveThreshold(sox_effect_t * effp, sox_ssample_t value, double threshold, int unit)
 {
     double ratio;
     int rc;
+    sox_ssample_t dummy_clipped_count = 0;
 
     /* When scaling low bit data, noise values got scaled way up */
     /* Only consider the original bits when looking for silence */
     switch(effp->ininfo.size)
     {
-        case ST_SIZE_BYTE:
-            value = ST_SAMPLE_TO_SIGNED_BYTE(value);
-            ratio = (double)abs(value) / (double)ST_INT8_MAX;
+        case SOX_SIZE_BYTE:
+            value = SOX_SAMPLE_TO_SIGNED_8BIT(value, dummy_clipped_count);
+            ratio = (double)abs(value) / (double)SOX_INT8_MAX;
             break;
-        case ST_SIZE_WORD:
-            value = ST_SAMPLE_TO_SIGNED_WORD(value);
-            ratio = (double)abs(value) / (double)ST_INT16_MAX;
+        case SOX_SIZE_16BIT:
+            value = SOX_SAMPLE_TO_SIGNED_16BIT(value, dummy_clipped_count);
+            ratio = (double)abs(value) / (double)SOX_INT16_MAX;
             break;
-        case ST_SIZE_DWORD:
-            value = ST_SAMPLE_TO_SIGNED_DWORD(value);
-            ratio = (double)labs(value) / (double)ST_INT32_MAX;
+        case SOX_SIZE_24BIT:
+            value = SOX_SAMPLE_TO_SIGNED_24BIT(value, dummy_clipped_count);
+            ratio = (double)abs(value) / (double)SOX_INT24_MAX;
+            break;
+        case SOX_SIZE_32BIT:
+            value = SOX_SAMPLE_TO_SIGNED_32BIT(value,);
+            ratio = (double)labs(value) / (double)SOX_INT32_MAX;
             break;
         default:
             ratio = 0;
@@ -367,11 +306,11 @@ int aboveThreshold(eff_t effp, st_sample_t value, double threshold, char unit)
     return rc;
 }
 
-static st_sample_t compute_rms(eff_t effp, st_sample_t sample)
+static sox_ssample_t compute_rms(sox_effect_t * effp, sox_ssample_t sample)
 {
     silence_t silence = (silence_t) effp->priv;
     double new_sum;
-    st_sample_t rms;
+    sox_ssample_t rms;
 
     new_sum = silence->rms_sum;
     new_sum -= *silence->window_current;
@@ -382,7 +321,7 @@ static st_sample_t compute_rms(eff_t effp, st_sample_t sample)
     return (rms);
 }
 
-static void update_rms(eff_t effp, st_sample_t sample)
+static void update_rms(sox_effect_t * effp, sox_ssample_t sample)
 {
     silence_t silence = (silence_t) effp->priv;
 
@@ -397,13 +336,13 @@ static void update_rms(eff_t effp, st_sample_t sample)
 
 /* Process signed long samples from ibuf to obuf. */
 /* Return number of samples processed in isamp and osamp. */
-int st_silence_flow(eff_t effp, st_sample_t *ibuf, st_sample_t *obuf, 
-                    st_size_t *isamp, st_size_t *osamp)
+static int sox_silence_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *obuf, 
+                    sox_size_t *isamp, sox_size_t *osamp)
 {
     silence_t silence = (silence_t) effp->priv;
-    int threshold, j;
-    st_size_t i;
-    st_size_t nrOfTicks, nrOfInSamplesRead, nrOfOutSamplesWritten;
+    int threshold;
+    sox_size_t i, j;
+    sox_size_t nrOfTicks, nrOfInSamplesRead, nrOfOutSamplesWritten;
 
     nrOfInSamplesRead = 0;
     nrOfOutSamplesWritten = 0;
@@ -494,21 +433,43 @@ silence_trim_flush:
             break;
 
         case SILENCE_COPY:
-            /* Attempts to copy samples into output buffer.  If not
-             * looking for silence to terminate copy then blindly
-             * copy data into output buffer.
+            /* Attempts to copy samples into output buffer.
              *
-             * If looking for silence, then see if input sample is above
-             * threshold.  If found then flush out hold off buffer
-             * and copy over to output buffer.  Tell user about
-             * input and output processing.
+             * Case B:
+             * If not looking for silence to terminate copy then
+             * blindly copy data into output buffer.
              *
-             * If not above threshold then store in hold off buffer
-             * and do not write to output buffer.  Tell user input
-             * was processed.
+             * Case A:
+             *
+             * Case 1a:
+             * If previous silence was detect then see if input sample is 
+             * above threshold.  If found then flush out hold off buffer
+             * and copy over to output buffer.  
+             *
+             * Case 1b:
+             * If no previous silence detect then see if input sample
+             * is above threshold.  If found then copy directly
+             * to output buffer.
+             *
+             * Case 2:
+             * If not above threshold then silence is detect so
+             * store in hold off buffer and do not write to output
+             * buffer.  Even though it wasn't put in output
+             * buffer, inform user that input was consumed.
+             *
+             * If hold off buffer is full after this then stop 
+             * copying data and discard data in hold off buffer.
+             *
+             * Special leave_silence logic:
+             *
+             * During this mode, go ahead and copy input
+             * samples to output buffer instead of holdoff buffer
+             * Then also short ciruit any flushes that would occur
+             * when non-silence is detect since samples were already
+             * copied.  This has the effect of always leaving
+             * holdoff[] amount of silence but deleting any
+             * beyond that amount.
              *
-             * If hold off buffer is full then stop copying data and
-             * discard data in hold off buffer.
              */
 silence_copy:
             nrOfTicks = min((*isamp-nrOfInSamplesRead), 
@@ -516,6 +477,7 @@ silence_copy:
                            effp->ininfo.channels;
             if (silence->stop)
             {
+                /* Case A */
                 for(i = 0; i < nrOfTicks; i++)
                 {
                     threshold = 1;
@@ -527,16 +489,24 @@ silence_copy:
                                                     silence->stop_unit);
                     }
 
-                    /* If above threshold, check to see if we where holding
+                    /* Case 1a
+                     * If above threshold, check to see if we where holding
                      * off previously.  If so then flush this buffer.
                      * We haven't incremented any pointers yet so nothing
                      * is lost.
+                     *
+                     * If user wants to leave_silence, then we
+                     * were already copying the data and so no
+                     * need to flush the old data.  Just resume
+                     * copying as if we were not holding off.
                      */
-                    if (threshold && silence->stop_holdoff_end)
+                    if (threshold && silence->stop_holdoff_end
+                        && !silence->leave_silence)
                     {
                         silence->mode = SILENCE_COPY_FLUSH;
                         goto silence_copy_flush;
                     }
+                    /* Case 1b */
                     else if (threshold)
                     {
                         /* Not holding off so copy into output buffer */
@@ -548,12 +518,17 @@ silence_copy:
                             nrOfOutSamplesWritten++;
                         }
                     }
+                    /* Case 2 */
                     else if (!threshold)
                     {
                         /* Add to holdoff buffer */
                         for (j = 0; j < effp->ininfo.channels; j++)
                         {
                             update_rms(effp, *ibuf);
+                            if (silence->leave_silence) {
+                                *obuf++ = *ibuf;
+                                nrOfOutSamplesWritten++;
+                            }
                             silence->stop_holdoff[
                                 silence->stop_holdoff_end++] = *ibuf++;
                             nrOfInSamplesRead++;
@@ -577,8 +552,8 @@ silence_copy:
                                     *isamp = nrOfInSamplesRead;
                                     *osamp = nrOfOutSamplesWritten;
                                     silence->mode = SILENCE_STOP;
-                                    /* Return ST_EOF since no more processing */
-                                    return (ST_EOF);
+                                    /* Return SOX_EOF since no more processing */
+                                    return (SOX_EOF);
                                 }
                                 else
                                 {
@@ -607,7 +582,8 @@ silence_copy:
             } /* Trimming off backend */
             else /* !(silence->stop) */
             {
-                memcpy(obuf, ibuf, sizeof(st_sample_t)*nrOfTicks*
+                /* Case B */
+                memcpy(obuf, ibuf, sizeof(sox_ssample_t)*nrOfTicks*
                                    effp->ininfo.channels);
                 nrOfInSamplesRead += (nrOfTicks*effp->ininfo.channels);
                 nrOfOutSamplesWritten += (nrOfTicks*effp->ininfo.channels);
@@ -644,14 +620,14 @@ silence_copy_flush:
         *isamp = nrOfInSamplesRead;
         *osamp = nrOfOutSamplesWritten;
 
-        return (ST_SUCCESS);
+        return (SOX_SUCCESS);
 }
 
-int st_silence_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
+static int sox_silence_drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t *osamp)
 {
     silence_t silence = (silence_t) effp->priv;
-    st_size_t i;
-    st_size_t nrOfTicks, nrOfOutSamplesWritten = 0;
+    sox_size_t i;
+    sox_size_t nrOfTicks, nrOfOutSamplesWritten = 0;
 
     /* Only if in flush mode will there be possible samples to write
      * out during drain() call.
@@ -678,36 +654,43 @@ int st_silence_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
 
     *osamp = nrOfOutSamplesWritten;
     if (silence->mode == SILENCE_STOP || *osamp == 0)
-        return ST_EOF;
+        return SOX_EOF;
     else
-        return ST_SUCCESS;
+        return SOX_SUCCESS;
 }
 
-int st_silence_stop(eff_t effp)
+static int sox_silence_stop(sox_effect_t * effp)
 {
     silence_t silence = (silence_t) effp->priv;
 
-    if (silence->window)
-        free(silence->window);
-    if (silence->start_holdoff)
-        free(silence->start_holdoff);
-    if (silence->stop_holdoff)
-        free(silence->stop_holdoff);
-    return(ST_SUCCESS);
+    free(silence->window);
+    free(silence->start_holdoff);
+    free(silence->stop_holdoff);
+    return(SOX_SUCCESS);
 }
 
-static st_effect_t st_silence_effect = {
+static int kill(sox_effect_t * effp)
+{
+  silence_t silence = (silence_t) effp->priv;
+
+  free(silence->start_duration_str);
+  free(silence->stop_duration_str);
+  return SOX_SUCCESS;
+}
+
+static sox_effect_handler_t sox_silence_effect = {
   "silence",
-  "Usage: silence above_periods [ duration thershold[d | %% ] ] [ below_periods duration threshold[ d | %% ]]",
-  ST_EFF_MCHAN,
-  st_silence_getopts,
-  st_silence_start,
-  st_silence_flow,
-  st_silence_drain,
-  st_silence_stop
+  "[ -l ] above_periods [ duration thershold[d|%%] ] [ below_periods duration threshold[d|%%]]",
+  SOX_EFF_MCHAN,
+  sox_silence_getopts,
+  sox_silence_start,
+  sox_silence_flow,
+  sox_silence_drain,
+  sox_silence_stop,
+  kill
 };
 
-const st_effect_t *st_silence_effect_fn(void)
+const sox_effect_handler_t *sox_silence_effect_fn(void)
 {
-    return &st_silence_effect;
+    return &sox_silence_effect;
 }
