@@ -18,57 +18,54 @@
  * Foundation, Fifth Floor, 51 Franklin Street, Boston, MA 02111-1301,
  * USA.  */
 
-#include "st_i.h"
+#include "sox_i.h"
 
 /* Private data for effect */
 typedef struct skeleff {
   int  localdata;
 } *skeleff_t;
 
-assert_static(sizeof(struct skeleff) <= ST_MAX_EFFECT_PRIVSIZE, 
+assert_static(sizeof(struct skeleff) <= SOX_MAX_EFFECT_PRIVSIZE, 
               /* else */ skeleff_PRIVSIZE_too_big);
 
 /*
- * Process command-line options
- *
- * Don't do initialization now.
- * The 'info' fields are not yet filled in.
+ * Process command-line options but don't do other
+ * initialization now: effp->ininfo & effp->outinfo are not
+ * yet filled in.
  */
-static int getopts(eff_t effp, int n, char **argv)
+static int getopts(sox_effect_t * effp, int n, char **argv)
 {
   skeleff_t skeleff = (skeleff_t)effp->priv;
 
-  if (n && n != 1) {
-    st_fail(effp->h->usage);
-    return ST_EOF;
-  }
+  if (n && n != 1)
+    return sox_usage(effp);
 
-  return ST_SUCCESS;
+  return SOX_SUCCESS;
 }
 
 /*
  * Prepare processing.
  * Do all initializations.
  */
-static int start(eff_t effp)
+static int start(sox_effect_t * effp)
 {
   if (effp->outinfo.channels == 1) {
-    st_fail("Can't run skeleff on mono data.");
-    return ST_EOF;
+    sox_fail("Can't run on mono data.");
+    return SOX_EOF;
   }
 
-  return ST_SUCCESS;
+  return SOX_SUCCESS;
 }
 
 /*
  * Processed signed long samples from ibuf to obuf.
  * Return number of samples processed.
  */
-static int flow(eff_t effp, const st_sample_t *ibuf, st_sample_t *obuf, 
-                           st_size_t *isamp, st_size_t *osamp)
+static int flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *obuf, 
+                           sox_size_t *isamp, sox_size_t *osamp)
 {
   skeleff_t skeleff = (skeleff_t)effp->priv;
-  st_size_t len, done;
+  sox_size_t len, done;
 
   switch (effp->outinfo.channels) {
   case 2:
@@ -91,63 +88,63 @@ static int flow(eff_t effp, const st_sample_t *ibuf, st_sample_t *obuf,
     break;
   }
 
-  return ST_SUCCESS;
+  return SOX_SUCCESS;
 }
 
 /*
  * Drain out remaining samples if the effect generates any.
  */
-static int drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
+static int drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t *osamp)
 {
   *osamp = 0;
-  /* Help out application and return ST_EOF when drain
-   * will not return any mre information.  *osamp == 0
-   * also indicates that.
+  /* Return SOX_EOF when drain
+   * will not output any more samples.
+   * *osamp == 0 also indicates that.
    */
-  return ST_EOF;
+  return SOX_EOF;
 }
 
 /*
  * Do anything required when you stop reading samples.  
  */
-static int stop(eff_t effp)
+static int stop(sox_effect_t * effp)
 {
-  return ST_SUCCESS;
+  return SOX_SUCCESS;
 }
 
 /*
- * Do anything required when you delete an effect.  
+ * Do anything required when you kill an effect.  
  *      (free allocated memory, etc.)
  */
-static int delete(eff_t effp)
+static int kill(sox_effect_t * effp)
 {
-  return ST_SUCCESS;
+  return SOX_SUCCESS;
 }
 
 
 /*
  * Effect descriptor.
  * If no specific processing is needed for any of
- * the 6 functions, then the function can be deleted
+ * the 6 functions, then the function above can be deleted
  * and 0 used in place of the its name below.
  */
-static st_effect_t st_skel_effect = {
+static sox_effect_handler_t sox_skel_effect = {
   "skel",
-  "Usage: skel [option]",
-  ST_EFF_MCHAN,
+  "[OPTION]",
+  SOX_EFF_MCHAN,
   getopts,
   start,
   flow,
   drain,
   stop,
-  delete,
+  kill,
 };
 
 /*
  * Function returning effect descriptor. This should be the only
  * externally visible object.
  */
-const st_effect_t *st_skel_effect_fn(void)
+const sox_effect_handler_t *sox_skel_effect_fn(void)
 {
-  return &st_skel_effect;
+  return &sox_skel_effect;
 }
