@@ -7,7 +7,7 @@
  *
  */
 
-#include "st_i.h"
+#include "sox_i.h"
 
 #include <math.h>
 #include <string.h>
@@ -16,7 +16,7 @@
 /* Private data for sphere file */
 typedef struct spherestuff {
         char      shorten_check[4];
-        st_size_t numSamples;
+        sox_size_t numSamples;
 } *sphere_t;
 
 /*
@@ -26,46 +26,46 @@ typedef struct spherestuff {
  *      size and encoding of samples, 
  *      mono/stereo/quad.
  */
-static int st_spherestartread(ft_t ft) 
+static int sox_spherestartread(sox_format_t * ft) 
 {
         sphere_t sphere = (sphere_t) ft->priv;
         int rc;
         char *buf;
         char fldname[64], fldtype[16], fldsval[128];
         int i;
-        int header_size, bytes_read;
+        sox_size_t header_size, bytes_read;
         long rate;
 
         /* Needed for rawread() */
-        rc = st_rawstartread(ft);
+        rc = sox_rawstartread(ft);
         if (rc)
             return rc;
 
         /* Magic header */
-        if (st_reads(ft, fldname, 8) == ST_EOF || strncmp(fldname, "NIST_1A", 7) != 0)
+        if (sox_reads(ft, fldname, 8) == SOX_EOF || strncmp(fldname, "NIST_1A", 7) != 0)
         {
-            st_fail_errno(ft,ST_EHDR,"Sphere header does not begin with magic mord 'NIST_1A'");
-            return(ST_EOF);
+            sox_fail_errno(ft,SOX_EHDR,"Sphere header does not begin with magic mord 'NIST_1A'");
+            return(SOX_EOF);
         }
 
-        if (st_reads(ft, fldsval, 8) == ST_EOF)
+        if (sox_reads(ft, fldsval, 8) == SOX_EOF)
         {
-            st_fail_errno(ft,ST_EHDR,"Error reading Sphere header");
-            return(ST_EOF);
+            sox_fail_errno(ft,SOX_EHDR,"Error reading Sphere header");
+            return(SOX_EOF);
         }
 
         /* Determine header size, and allocate a buffer large enough to hold it. */
-        sscanf(fldsval, "%d", &header_size);
-        buf = (char *)xmalloc(header_size);
+        sscanf(fldsval, "%u", &header_size);
+        buf = xmalloc(header_size);
 
         /* Skip what we have read so far */
         header_size -= 16;
 
-        if (st_reads(ft, buf, header_size) == ST_EOF)
+        if (sox_reads(ft, buf, header_size) == SOX_EOF)
         {
-            st_fail_errno(ft,ST_EHDR,"Error reading Sphere header");
+            sox_fail_errno(ft,SOX_EHDR,"Error reading Sphere header");
             free(buf);
-            return(ST_EOF);
+            return(SOX_EOF);
         }
 
         header_size -= (strlen(buf) + 1);
@@ -89,10 +89,10 @@ static int st_spherestartread(ft_t ft)
                 /* Only bother looking for ulaw flag.  All others
                  * should be caught below by default PCM check
                  */
-                if (ft->signal.encoding == ST_ENCODING_UNKNOWN && 
+                if (ft->signal.encoding == SOX_ENCODING_UNKNOWN && 
                     strncmp(fldsval,"ulaw",4) == 0)
                 {
-                    ft->signal.encoding = ST_ENCODING_ULAW;
+                    ft->signal.encoding = SOX_ENCODING_ULAW;
                 }
             }
             if (strncmp(buf, "sample_rate ", 12) == 0 &&
@@ -105,87 +105,69 @@ static int st_spherestartread(ft_t ft)
             {
                 sscanf(buf, "%53s %15s %127s", fldname, fldtype, fldsval);
                 if (strncmp(fldsval,"01",2) == 0)
-                  ft->signal.reverse_bytes = ST_IS_BIGENDIAN; /* Data is little endian. */
+                  ft->signal.reverse_bytes = SOX_IS_BIGENDIAN; /* Data is little endian. */
                 else if (strncmp(fldsval,"10",2) == 0)
-                  ft->signal.reverse_bytes = ST_IS_LITTLEENDIAN; /* Data is big endian. */
+                  ft->signal.reverse_bytes = SOX_IS_LITTLEENDIAN; /* Data is big endian. */
             }
 
-            if (st_reads(ft, buf, header_size) == ST_EOF)
+            if (sox_reads(ft, buf, header_size) == SOX_EOF)
             {
-                st_fail_errno(ft,ST_EHDR,"Error reading Sphere header");
+                sox_fail_errno(ft,SOX_EHDR,"Error reading Sphere header");
                 free(buf);
-                return(ST_EOF);
+                return(SOX_EOF);
             }
 
             header_size -= (strlen(buf) + 1);
         }
 
         if (ft->signal.size == -1)
-            ft->signal.size = ST_SIZE_BYTE;
+            ft->signal.size = SOX_SIZE_BYTE;
 
         /* sample_coding is optional and is PCM if missing.
          * This means encoding is signed if size = word or
          * unsigned if size = byte.
          */
-        if (ft->signal.encoding == ST_ENCODING_UNKNOWN)
+        if (ft->signal.encoding == SOX_ENCODING_UNKNOWN)
         {
             if (ft->signal.size == 1)
-                ft->signal.encoding = ST_ENCODING_UNSIGNED;
+                ft->signal.encoding = SOX_ENCODING_UNSIGNED;
             else
-                ft->signal.encoding = ST_ENCODING_SIGN2;
+                ft->signal.encoding = SOX_ENCODING_SIGN2;
         }
 
         while (header_size)
         {
-            bytes_read = st_readbuf(ft, buf, ST_SIZE_BYTE, header_size);
+            bytes_read = sox_readbuf(ft, buf, header_size);
             if (bytes_read == 0)
             {
                 free(buf);
-                return(ST_EOF);
+                return(SOX_EOF);
             }
             header_size -= bytes_read;
         }
 
         sphere->shorten_check[0] = 0;
 
-        /* Check first four bytes of data to see if it's shorten
-         * compressed or not.
-         */
-        st_reads(ft, sphere->shorten_check, 4);
+        if (ft->seekable) {
+          /* Check first four bytes of data to see if it's shorten compressed. */
+          sox_ssize_t pos = sox_tell(ft);
+          sox_reads(ft, sphere->shorten_check, 4);
 
-        if (!strcmp(sphere->shorten_check,"ajkg"))
-        {
-            st_fail_errno(ft,ST_EFMT,"File uses shorten compression, cannot handle this.");
+          if (!strcmp(sphere->shorten_check,"ajkg")) {
+            sox_fail_errno(ft, SOX_EFMT, "File uses shorten compression, cannot handle this.");
             free(buf);
-            return(ST_EOF);
+            return(SOX_EOF);
+          }
+
+          /* Can't just seek -4, as sox_reads has read 1-4 bytes */
+          sox_seeki(ft, pos, SEEK_SET); 
         }
 
         free(buf);
-        return (ST_SUCCESS);
+        return (SOX_SUCCESS);
 }
 
-/*
- * Read up to len samples from file.
- * Convert to signed longs.
- * Place in buf[].
- * Return number of samples read.
- */
-
-static st_size_t st_sphereread(ft_t ft, st_sample_t *buf, st_size_t len) 
-{
-    sphere_t sphere = (sphere_t) ft->priv;
-
-    if (sphere->shorten_check[0])
-    {
-        /* TODO: put these 4 bytes into the buffer.  Requires
-         * knowing how to process ulaw and all version of PCM data size.
-         */
-        sphere->shorten_check[0] = 0;
-    }
-    return st_rawread(ft, buf, len);
-}
-
-static int st_spherestartwrite(ft_t ft) 
+static int sox_spherestartwrite(sox_format_t * ft) 
 {
     int rc;
     int x;
@@ -193,91 +175,91 @@ static int st_spherestartwrite(ft_t ft)
 
     if (!ft->seekable)
     {
-        st_fail_errno(ft,ST_EOF,"File must be seekable for sphere file output");
-        return (ST_EOF);
+        sox_fail_errno(ft,SOX_EOF,"File must be seekable for sphere file output");
+        return (SOX_EOF);
     }
 
     switch (ft->signal.encoding)
     {
-        case ST_ENCODING_ULAW:
-        case ST_ENCODING_SIGN2:
-        case ST_ENCODING_UNSIGNED:
+        case SOX_ENCODING_ULAW:
+        case SOX_ENCODING_SIGN2:
+        case SOX_ENCODING_UNSIGNED:
             break;
         default:
-            st_fail_errno(ft,ST_EFMT,"SPHERE format only supports ulaw and PCM data.");
-            return(ST_EOF);
+            sox_fail_errno(ft,SOX_EFMT,"SPHERE format only supports ulaw and PCM data.");
+            return(SOX_EOF);
     }
 
     sphere->numSamples = 0;
 
     /* Needed for rawwrite */
-    rc = st_rawstartwrite(ft);
+    rc = sox_rawstartwrite(ft);
     if (rc)
         return rc;
 
     for (x = 0; x < 1024; x++)
     {
-        st_writeb(ft, ' ');
+        sox_writeb(ft, ' ');
     }
 
-    return(ST_SUCCESS);
+    return(SOX_SUCCESS);
         
 }
 
-static st_size_t st_spherewrite(ft_t ft, const st_sample_t *buf, st_size_t len) 
+static sox_size_t sox_spherewrite(sox_format_t * ft, const sox_ssample_t *buf, sox_size_t len) 
 {
     sphere_t sphere = (sphere_t) ft->priv;
 
     sphere->numSamples += len; /* must later be divided by channels */
-    return st_rawwrite(ft, buf, len);
+    return sox_rawwrite(ft, buf, len);
 }
 
-static int st_spherestopwrite(ft_t ft) 
+static int sox_spherestopwrite(sox_format_t * ft) 
 {
     int rc;
     char buf[128];
     sphere_t sphere = (sphere_t) ft->priv;
     long samples, rate;
 
-    rc = st_rawstopwrite(ft);
+    rc = sox_rawstopwrite(ft);
     if (rc)
         return rc;
 
-    if (st_seeki(ft, 0, 0) != 0)
+    if (sox_seeki(ft, 0, 0) != 0)
     {
-        st_fail_errno(ft,errno,"Could not rewird output file to rewrite sphere header.");
-        return (ST_EOF);
+        sox_fail_errno(ft,errno,"Could not rewird output file to rewrite sphere header.");
+        return (SOX_EOF);
     }
 
-    st_writes(ft, "NIST_1A\n");
-    st_writes(ft, "   1024\n");
+    sox_writes(ft, "NIST_1A\n");
+    sox_writes(ft, "   1024\n");
 
     samples = sphere->numSamples/ft->signal.channels;
     sprintf(buf, "sample_count -i %ld\n", samples);
-    st_writes(ft, buf);
+    sox_writes(ft, buf);
 
     sprintf(buf, "sample_n_bytes -i %d\n", ft->signal.size);
-    st_writes(ft, buf);
+    sox_writes(ft, buf);
 
     sprintf(buf, "channel_count -i %d\n", ft->signal.channels);
-    st_writes(ft, buf);
+    sox_writes(ft, buf);
 
     sprintf(buf, "sample_byte_format -s2 %s\n",
-        ft->signal.reverse_bytes != ST_IS_BIGENDIAN ? "10" : "01");
-    st_writes(ft, buf);
+        ft->signal.reverse_bytes != SOX_IS_BIGENDIAN ? "10" : "01");
+    sox_writes(ft, buf);
 
     rate = ft->signal.rate;
     sprintf(buf, "sample_rate -i %ld\n", rate);
-    st_writes(ft, buf);
+    sox_writes(ft, buf);
 
-    if (ft->signal.encoding == ST_ENCODING_ULAW)
-        st_writes(ft, "sample_coding -s4 ulaw\n");
+    if (ft->signal.encoding == SOX_ENCODING_ULAW)
+        sox_writes(ft, "sample_coding -s4 ulaw\n");
     else
-        st_writes(ft, "sample_coding -s3 pcm\n");
+        sox_writes(ft, "sample_coding -s3 pcm\n");
 
-    st_writes(ft, "end_head\n");
+    sox_writes(ft, "end_head\n");
 
-    return (ST_SUCCESS);
+    return (SOX_SUCCESS);
 }
 
 /* NIST Sphere File */
@@ -287,20 +269,21 @@ static const char *spherenames[] = {
   NULL
 };
 
-static st_format_t st_sphere_format = {
+static sox_format_handler_t sox_sphere_format = {
   spherenames,
-  NULL,
   0,
-  st_spherestartread,
-  st_sphereread,
-  st_rawstopread,
-  st_spherestartwrite,
-  st_spherewrite,
-  st_spherestopwrite,
-  st_format_nothing_seek
+  sox_spherestartread,
+  sox_rawread,
+  sox_rawstopread,
+  sox_spherestartwrite,
+  sox_spherewrite,
+  sox_spherestopwrite,
+  sox_format_nothing_seek
 };
 
-const st_format_t *st_sphere_format_fn(void)
+const sox_format_handler_t *sox_sphere_format_fn(void);
+
+const sox_format_handler_t *sox_sphere_format_fn(void)
 {
-    return &st_sphere_format;
+    return &sox_sphere_format;
 }
